#!/bin/sh

printf '%s' \
'/*!
 * mkpicindex.sh - v0.1
 * https://codevoid.de
 * Copyright (c) 2019 Stefan Hagen
 * Licensed under the ISC license.
 * 
 * style.css, justify.js:
 * justifiedGallery - v4.0.0-alpha
 * http://miromannino.github.io/Justified-Gallery/
 * Copyright (c) 2019 Miro Mannino
 * Licensed under the MIT license.
 */
' > LICENSE

# CONFIGURE
GALLERY_TITLE="My Gallery" # browser title
GALLERY_ROW_HEIGHT=150     # how high will the justified rows be?
GALLERY_RANDOMIZE=false     # enable random sorting (true,false)
BODY_STYLE="color:orange; background:black;" # <body style="?">
THUMBNAIL_QUALITY=83       # quality for thumbnails
THUMBNAIL_PATH="thm"       # relative path to thumbnail folder
INCLUDE_HEADER="HEADER"    # file with html to include before gallery
INCLUDE_FOOTER="FOOTER"    # file with html to include after gallery

### ZE PROGAM STARTZ HERE ##############################################
cleanup() {
    # DELETE BROKEN IMAGES
    printf '%s\n' "Removing incomplete thumbnails." >&2
    find $THUMBNAIL_PATH -name "*_tmp.*" -exec rm -v "{}" \;
    exit 1
}
trap cleanup 1 2 3 6

# CREATE THUMBNAIL DIRECTORY
mkdir -p $THUMBNAIL_PATH

# INCLUDE CUSTOM HEADER & FOOTER
FOOTER=$([ -f $INCLUDE_FOOTER ] && cat $INCLUDE_FOOTER | sed 's/^/        /g')
HEADER=$([ -f $INCLUDE_HEADER ] && cat $INCLUDE_HEADER | sed 's/^/        /g')

# PRINT HEADER
printf '%s%s%s%s%s\n' \
'<html>
    <head>
        <title>'"$GALLERY_TITLE"'</title>
        <meta name="viewport" content="width=device-width">
        <link href="style.css" rel="stylesheet">
        <script src="justify.js"></script>
    </head>
    <body style="'"$BODY_STYLE"'">
'       "$HEADER"'
        <div id="base">'


# RESCALE AND ADD IMAGE
# PARAM 1: original
#       2: thumbnail_basename
#       3: thumbnail_format (extension)
add_image() {
    local FILE="$1"
    local THUMB="$THUMBNAIL_PATH/$2-$GALLERY_ROW_HEIGHT"
    local EXT="$3"
    printf '%s\n' "Adding image: $FILE" >&2
    if ! [ -f "$THUMB.$EXT" ] && [ "$FILE" != "$THUMB.$EXT" ];
        then convert -quality $THUMBNAIL_QUALITY -sharpen 2x2 \
                     -coalesce -resize 6000x$GALLERY_ROW_HEIGHT\> \
                     -deconstruct "$FILE" "${THUMB}_tmp.$EXT" && \
        mv "${THUMB}_tmp.$EXT" "$THUMB.$EXT"
    fi
    local WH="$(identify -format ' %w %h ' "$THUMB.$EXT" \
                | awk '{ print "width="$1" height="$2 }')"
    printf '            %s\n' "<a href=\"$FILE\">"
    printf '                %s\n' "<img $WH src=\"$THUMB.$EXT\">"
    printf '            %s\n' '</a>'
}

### MAIN LOOP ##########################################################

for file in *.*;
do
    if [ -f "$file" ];
    then
        case $(printf '%s' ${file##*.} | tr '[:upper:]' '[:lower:]') in
            jpg|jpeg|png) 
                add_image "$file" "${file%%.*}" "jpeg" ;;
            gif)
                add_image "$file" "${file%%.*}" "gif" ;;
            *) printf '%s\n' "Ignoring: $file" >&2 ;;
        esac
    fi
done

### MAIN LOOP END ######################################################

# PRINT FOOTER
printf '%s%s\n' \
"        </div>
        <script>
            \$(\"#base\").justifiedGallery({
                rowHeight : $GALLERY_ROW_HEIGHT/0.8,
                maxRowHeight : $GALLERY_ROW_HEIGHT,
                randomize : $GALLERY_RANDOMIZE,
                waitThumbnailsLoad : false,
                lastRow : \"nojustify\",
                margins : 3
            });
        </script>
"        "$FOOTER
    </body>
</html>"

### ASSETS (style.css, justify.js) #####################################
printf '%s' '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' | base64 -d | gunzip > justify.js


printf '%s' '
H4sICOujrl0AA3N0eWxlLmNzcwDVVk1vnDAQve+vmCaqlEQ1y6abJiVKLz1UrZJb/oABA5MY
G9lmN5sq/73GfKzYBUKORVotY7/xzDyPH15efFrABTyV2mCCLP5FOWdqBwQ2a8/3fEJ5kdEK
khlTBMtljkrmVAgU0kvRZGXooVz+af1Js8Cycvkpi53CNDNwFp3Dpb/6Dg/WHR5q/wpyjxET
msVQipgpMBmDh9+PwOthz0KWC6/LjqRNen8XAFuMTRbAyvc/31qzkBoNShGAYpwa3LBqVG6Y
SrjcBpBhHDNxu3gbWu8H0C/D4zFuRmYSTEvFXCr72DTUkpfGxY5RF5zuAkDBUTASchk9DycF
sLyAkEbPqZKWiQBOb9xzC48SMrphkCq6A7tcxDLJLVUathly5hhrc0INXNIYRWrJMRlsKZrH
rMxDQZHrezsFd5BQrllFK9gKuGEqgBO3yWeyoBGa3d3KPz9xadZ2AL63quycqhRtjb6jm8ZV
IGeNUWp/mKfjxE7ON/ROQejMINOYLtA0rJrVm+lA4/NdkHEInRlkGtOrxsIm+tPIIoCr+vRw
lpjOGN1ogFCquGoZIYVbY6SFjjposkm8iBZVepNlvwPq6m5xrvDuCLb5DjMRSmNkfljwVfHi
JrtjSSLJpS321HfPnjf36pSuee8x2HjZ81pHS6QwROMrs+J1WcdwQ1tWr/C1XtqNJTRHbvPX
VGiimcJkFpPtP9mgxpCzWczOdDpi+tCvzzwKSzjlE81yfaw315VtCQmf0RCjbPHNrjUY26l+
roFRzQg6/SS5fJ2JlPNwM0AjO+E9pYQJo3Y9RkbV9rD8Vb/r2uadHWxKxYbQ07o35DEuP2Pr
t0r0MRL+6w6oS7VXmwEhGnPTBQph70Hjot2TqlpmSC1C5HJdi0knYCu/eAG/+TtS+Y9txf7O
0h3o94qwu15QcagG/avQ/O9Hd+G7qavMGrVszE5xYe2KXk+J9/5LRpS9L5U6gG8V/m3xD0Dc
I3kQCwAA
' | base64 -d | gunzip > style.css
